# Example Package

This is a test re_name package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

#e_name -p '\-\d' ""
hello1-1.txt  ---->  hello1.txt

#re_name 55 ll -s "#"
he55o1.txt  ---->  hello1-1.txt
he55o2.txt  ---->  hello2-2.txt
he55o3.txt  ---->  hello3-3.txt